@@ -133,3 +133,42 @@ def json_dump(data):
 
 def json_load(data: str):
     return json.loads(data, object_hook=obj_hook)
+
+
+class SortedObj(object):
+    """可排序对象"""
+
+    def __init__(self):
+        import time
+        self.__created_at__ = time.time() * 10000
+
+    def __lt__(self, other: "SortedObj"):
+        return self.__created_at__ < other.__created_at__
+
+    def __gt__(self, other: "SortedObj"):
+        return self.__created_at__ > other.__created_at__
+
+
+def data_filter(data, key_filter=None, val_filter=None):
+    _type_func = {
+        'dict': lambda x: dict(x),
+        'list': lambda x: list(dict(x).values()),
+    }
+
+    if isinstance(data, list):
+        _type = 'list'
+        tmp = enumerate(data)
+    elif isinstance(data, dict):
+        _type = 'dict'
+        tmp = data.items()
+    else:
+        return data
+
+    if not (key_filter or val_filter):
+        tmp = [(k, v) for k, v in tmp if v]
+    else:
+        if key_filter and isinstance(key_filter, (list, tuple)):
+            tmp = [(k, v) for k, v in tmp if k in key_filter]
+        if val_filter and isinstance(val_filter, (list, tuple)):
+            tmp = [(k, v) for k, v in tmp if v not in val_filter]
+    return _type_func[_type](tmp)
